==> pwkit-1.2.0.tar.gz: pwkit-1.2.0/README.md <==
[![Build Status](https://dev.azure.com/peter-bulk/Misc/_apis/build/status%2Fpkgw.pwkit?branchName=master)](https://dev.azure.com/peter-bulk/Misc/_build/latest?definitionId=10&branchName=master)

# pwkit: miscellaneous Python for science and astronomy

<!--pypi-begin-->
This is a collection of Peter Williams’ miscellaneous Python tools.
<!--pypi-end-->

The online documentation contains [installation instructions]. The
documentation is very much a work in progress but [may be found here].

[installation instructions]: http://pwkit.readthedocs.org/en/latest/about/#installation
[may be found here]: http://pwkit.readthedocs.org/en/latest/


## Citation

<!-- Note: this text is mirrored in docs/source/about.rst -->

If you use pwkit in academic work, you should identify that you have done so
and specify the version used. While pwkit does not (yet?) have an accompanying
formal publication, in journals like [ApJ] you can “cite” the code directly via [its
record] in the [NASA Astrophysics Data System], which has identifier
[2017ascl.soft04001W]. This corresponds to record [ascl:1704.001] in the
[Astrophysics Source Code Library]. By clicking on [this link] you can
get the ADS-recommended BibTeX record for the reference.

[ApJ]: http://iopscience.iop.org/journal/0004-637X
[its record]: https://ui.adsabs.harvard.edu/abs/2017ascl.soft04001W/abstract
[NASA Astrophysics Data System]: https://ui.adsabs.harvard.edu/
[2017ascl.soft04001W]: https://ui.adsabs.harvard.edu/abs/2017ascl.soft04001W/abstract
[ascl:1704.001]: http://ascl.net/1704.001
[Astrophysics Source Code Library]: http://ascl.net/
[this link]: http://adsabs.harvard.edu/cgi-bin/nph-bib_query?bibcode=2017ascl.soft04001W&data_type=BIBTEX

If you are using [aastex] version 6 or higher, the appropriate code to
include after your Acknowledgments section would be:

[aastex]: http://journals.aas.org/authors/aastex.html

```tex
\software{..., pwkit \citep{2017ascl.soft04001W}, ...}
```


## Authors

See the [online documentation].

[online documentation]: http://pwkit.readthedocs.org/en/latest/about/#authors


## License

The [MIT license]. See the file LICENSE in the source tree.

[MIT license]: http://opensource.org/licenses/MIT

==> pwkit-1.2.2.tar.gz: pwkit-1.2.2/README.md <==
[![Build Status](https://dev.azure.com/peter-bulk/Misc/_apis/build/status%2Fpkgw.pwkit?branchName=master)](https://dev.azure.com/peter-bulk/Misc/_build/latest?definitionId=10&branchName=master)

# pwkit: miscellaneous Python for science and astronomy

<!--pypi-begin-->
This is a collection of Peter Williams’ miscellaneous Python tools.
<!--pypi-end-->

The online documentation contains [installation instructions]. The
documentation is very much a work in progress but [may be found here].

[installation instructions]: https://pwkit.readthedocs.io/en/latest/about.html#installation
[may be found here]: https://pwkit.readthedocs.io/en/latest/


## Citation

<!-- Note: this text is mirrored in docs/source/about.rst -->

If you use pwkit in academic work, you should identify that you have done so
and specify the version used. While pwkit does not (yet?) have an accompanying
formal publication, in journals like [ApJ] you can “cite” the code directly via [its
record] in the [NASA Astrophysics Data System], which has identifier
[2017ascl.soft04001W]. This corresponds to record [ascl:1704.001] in the
[Astrophysics Source Code Library]. By clicking on [this link] you can
get the ADS-recommended BibTeX record for the reference.

[ApJ]: http://iopscience.iop.org/journal/0004-637X
[its record]: https://ui.adsabs.harvard.edu/abs/2017ascl.soft04001W/abstract
[NASA Astrophysics Data System]: https://ui.adsabs.harvard.edu/
[2017ascl.soft04001W]: https://ui.adsabs.harvard.edu/abs/2017ascl.soft04001W/abstract
[ascl:1704.001]: http://ascl.net/1704.001
[Astrophysics Source Code Library]: http://ascl.net/
[this link]: http://adsabs.harvard.edu/cgi-bin/nph-bib_query?bibcode=2017ascl.soft04001W&data_type=BIBTEX

If you are using [aastex] version 6 or higher, the appropriate code to
include after your Acknowledgments section would be:

[aastex]: http://journals.aas.org/authors/aastex.html

```tex
\software{..., pwkit \citep{2017ascl.soft04001W}, ...}
```


## Authors

See the [online documentation].

[online documentation]: https://pwkit.readthedocs.io/en/latest/about.html#authors


## License

The [MIT license]. See the file LICENSE in the source tree.

[MIT license]: http://opensource.org/licenses/MIT
